stringtools.arg_to_tridirectional_direction_string
==================================================

.. autofunction:: abjad.tools.stringtools.arg_to_tridirectional_direction_string.arg_to_tridirectional_direction_string
